<?php
/**
 * DokuWiki bethico Template
 * (c) 2014-2022, Bernard Condrau
 * 
 * 2022-10-06: main template file doku.php
 *             main.php is a 1:1 copy to allow DokuWiki to display correctly after an update before modifying DokuWiki's main php file
 *             cp doku.php main.php
 * 2022-10-09: new link to top of page, fixed some css, changed call to translation plugin, removed globals, changed logic to get identity
 */

if (!defined('DOKU_INC')) die();

require_once(dirname(__FILE__).'/styles/icons.php');
require_once(dirname(__FILE__).'/tpl_functions.php');
require_once(dirname(__FILE__).'/tpl_menu.php');
require_once(dirname(__FILE__).'/tpl_copyright.php');

// identity of this DokuWiki
tpl_bethico_set_identity();

// template theme
$tplStyle = tpl_getConf('style');
//$tpl_bethico_identity = tpl_getConf('identity');
$tplSidebarIcons = tpl_getConf('sidebaricons');
if (file_exists(tpl_incdir().'styles/style.'.$tplStyle.'.ini')) copy (tpl_incdir().'styles/style.'.$tplStyle.'.ini', tpl_incdir().'style.ini'); else copy (tpl_incdir().'styles/style.default.ini', tpl_incdir().'style.ini');

header('X-UA-Compatible: IE=edge,chrome=1');

echo '<!DOCTYPE html>';
echo '<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="'.$conf['lang'].'" lang="'.$conf['lang'].'" dir="'.$lang['direction'].'" class="no-js">';
echo '<head>';
	echo '<meta charset="UTF-8" />';
	echo '<title>'.tpl_pagetitle(null, true).'['.strip_tags($conf['title']).']</title>';
	echo '<script>(function(H){H.className=H.className.replace(/\bno-js\b/,\'js\')})(document.documentElement)</script>';
	tpl_metaheaders();
	echo '<meta name="viewport" content="width=device-width,initial-scale=1" />';
	echo tpl_favicon(array('favicon', 'mobile'));
	tpl_includeFile('meta.html');

	$dir = tpl_basedir();
	// FontAwesome is required for the base functionality of the template. Load them here, disable loading in plugin:icons.
	echo '<link href="'.tpl_basedir().'css/font-awesome.min.css" rel="stylesheet" type="text/css">';
	echo '<link href="'.tpl_basedir().'css/fa-v4-shims.css" rel="stylesheet" type="text/css">';
	if ($tplSidebarIcons) echo '<style>.m1-sidebox a.wikilink1,.m1-sidebox a.wikilink2 {margin-left:25px}.m1-sidebox ul {list-style:none}.m1-sidebox li {margin:0}</style>';
echo '</head>';

echo '<body>';
	echo '<div id="dokuwiki__site">';
		echo '<div id="dokuwiki__top" class="site '.tpl_classes().' hasSidebar">';
			html_msgarea(); // occasional error and info messages on top of the page
/*
			// language
			$translation = plugin_load('helper','translation');
			if ($translation) {
				tpl_bethico_set_prefix($translation);
				tpl_bethico_lang_overrides($translation);
			}
*/
			// set language prefix
			$translate = tpl_bethico_init_language(plugin_load('helper','translation'));
			
			// header and menus
			include('header.php');

			// page
			echo '<div id="m1-pagewrapper">'; // Used to control site width on desktop browsers

				// content
				echo '<div id="dokuwiki__content">';
					tpl_flush();
					echo '<div class="page">';
						tpl_content(); //the main content
						echo $INPUT->get->str('html');
						echo '<div class="clearer"></div>';
					echo '</div>';
					tpl_flush();
				echo '</div>'; // dokuwiki__content

				// sidebar
				echo '<div id="dokuwiki__aside">';
					echo '<div class="m1-sidebox">';
						if ($translate) echo '<div class="languageswitcher">'.$translate->showTranslations().'</div>';
						tpl_bethico_main_menu('side');
						tpl_bethico_side_menu();
					echo '</div>';
					echo '<div class="clearer"></div>';
				echo '</div>'; // aside

			echo '</div>'; // m1-pagewrapper

			// go-to-top of page link
			echo '<a href="#" id="sp-scroll-up" class="sp-scroll-up" aria-label="Scroll Up">';
				echo '<span class="fas fa-angle-up" aria-hidden="true"></span>';
			echo '</a>';
			echo '<script>s=document.getElementById("sp-scroll-up");var myScrollFunc=function(){var y=window.scrollY;if(y>=200){s.style.display="inline";}else{s.style.display="none";}};window.addEventListener("scroll", myScrollFunc);</script>';

			// footer
			echo '<div id="dokuwiki__footer">';
				echo '<div class="license">';
					echo '&copy; '.BETHICO_START_YEAR.(date('Y') > BETHICO_START_YEAR ? '-'.date('Y') : '').' '.BETHICO_OWNER_COPYRIGHT.BETHICO_USER_COPYRIGHT;
					if (tpl_bethico_user_group('admin')) {
						echo ' - '.tpl_getLang('poweredby').' '.BETHICO_WIKI_COPYRIGHT;
						if ($version=trim(file_get_contents(dirname(__FILE__).'/../../../VERSION'))) echo ' ('.$version.')';
						echo '<div class="docref">'.tpl_pageinfo().'</div>';
					}
				echo '</div>';
			echo '</div>'; // dokuwiki__footer
		echo '</div>'; // dokuwiki__top
	echo '</div>'; // dokuwiki__site

	echo '<div class="no">';
		tpl_indexerWebBug();
	echo '</div>';
echo '</body>';
echo '</html>';
