<?php
/**
 * DokuWiki bethico Template
 * (c) 2014-2020, Bernard Condrau
 * 
 * 2022-10-09: added login menu overrides taken from template language file, removed tpl_bethico_set_prefix and tpl_bethico_lang_overrides
 *             twofactor profile
 *
 * This file provides template specific custom functions that are
 * not provided by the DokuWiki core.
 */

// must be run from within DokuWiki
if (!defined('DOKU_INC')) die();

/**
 * Debug function, for internal use only
 * @param unknown $var
 */
function _bethico_debug(&$var) {
	ob_start();
	var_dump($var);
	file_put_contents(".bethico.debug.txt", ob_get_clean());
}
/**
 * Set prefix to always link to same language namespace
 * @param unknown $translation
 */
/*
function tpl_bethico_set_prefix($translation) {

	global $tpl_bethico_prefix, $ID;

	$tpl_bethico_prefix = $translation->defaultlang.':'; // default if not in language namespace
	if (strpos($ID, ':')==2 && in_array(substr($ID, 0, 2), $translation->translations)) {
		$tpl_bethico_prefix = substr($ID, 0, 3);
	}
}
*/
/**
 * Set DokuWiki identity
 */
function tpl_bethico_set_identity() {

	global $tpl_bethico_identity;

	$tpl_bethico_identity = tpl_getConf('identity');
}
/**
 * Set prefix to always link to same language namespace
 * @param unknown $translation
 */
 function tpl_bethico_init_language($plugin) {

	global $tpl_bethico_prefix, $ID;

	if ($plugin) {
		$tpl_bethico_prefix = $plugin->defaultlang.':'; // default if not in language namespace
		if (strpos($ID, ':')==2 && in_array(substr($ID, 0, 2), $plugin->translations)) {
			$tpl_bethico_prefix = substr($ID, 0, 3);
		}
	} else {
		$tpl_bethico_prefix = '';
	}
	return $plugin;
}
/**
 * Load main language overrides here, so the overrides do not need to be loaded in main code
 * @param unknown $translation
 */
/*
function tpl_bethico_lang_overrides($translation) {
	
	global $tpl_bethico_prefix, $lang;
	
	if ($tpl_bethico_prefix != 'en:') {
		$lc = substr($tpl_bethico_prefix, 0, 2);
		if ($lcfile = tpl_incdir().'core/lang/'.$lc.'/lang.php') include($lcfile);
	}
}
*/
/**
 * authorize user group
 * @author bco, 2020-05-03
 * @param unknown $user: 'user', 'admin'
 * @return boolean
 */
function tpl_bethico_user_group($user) {
	global $INFO;
	return (isset($INFO['userinfo']['grps']) && is_array($INFO['userinfo']['grps']) && in_array($user, $INFO['userinfo']['grps']));
}
/**
 * button function for content and sidebar
 * @author bco, 2020-05-01
 * @param unknown $type
 * @param unknown $link
 * @param unknown $style
 * @param string $task
 * compatible to plugin:button, also in template css
 */
function tpl_bethico_button($type, $link, $style, $task = '') {
	global $bethico_icons;

	if ($task) $task = '&do='.$task;
	$icon = explode('><', $bethico_icons[$type]);

	echo '<p>';
		echo '<a href="doku.php?id='.$link.$task.'">';
			echo '<span class="plugin_button">';
				echo '<span class="plugin_button_text wikilink1">';
					$test = $icon[0].($style ? ' style="'.$style.'"' : '').'><'.$icon[1].' '.tpl_getLang($type);
					echo $icon[0].($style ? ' style="'.$style.'"' : '').'><'.$icon[1].' '.tpl_getLang($type);
				echo '</span>';
			echo '</span>';
		echo '</a>';
	echo '</p>';
}
function tpl_bethico_login_menu_items() {

	global $INPUT;
	$disable = array('source', 'show', 'revs', 'media');

	$useritems = (new \dokuwiki\Menu\UserMenu())->getItems();
	$pageitems = (new \dokuwiki\Menu\PageMenu())->getItems();
	$siteitems = (new \dokuwiki\Menu\SiteMenu())->getItems();
	
	// reorder menu and remove some items from guest menu
	if ($INPUT->server->str('REMOTE_USER')) {
		$edititems = array($useritems[0], array_shift($pageitems));
		$items = array_merge($edititems, array_reverse($pageitems), $siteitems, $useritems);
	} else {
		foreach ($pageitems AS $index => $item) if (in_array($item->getType(), $disable)) unset($pageitems[$index]);
		foreach ($siteitems AS $index => $item) if (in_array($item->getType(), $disable)) unset($siteitems[$index]);
		$items = array_merge(array_reverse($useritems), array_reverse($pageitems), $siteitems);
	}
	return $items;
}
/**
 * get tags for menus
 * @param unknown $position: 'head', 'mobile', or 'side'
 * @param unknown $entries: number of menu entries including main entry
 * @param unknown $open: returns open tags per menu entry
 * @param unknown $close: returns close tags per menu entry
 *  tag analysis: <open>entry<close>, separated by ' ', 'head' and 'mobile' need embracing '<ul></ul>'
 *	head1:	<li>1</li>
 *	head9:	<li>1      <ul><li>2</li> <li>9</li></ul></li>
 *	mobile:	<li>1</li>     <li>2</li> <li>9</li>
 *	side:	<h2>1</h2> <ul><li>2</li> <li>9</li></ul>
 * preg_match_all('/(<[a-z]*>)|(<\/[a-z]*>)/', $tags, $matches); open tags -> $matches[1], close tags -> $matches[2]
 */
function tpl_bethico_getTags($position, $entries, &$open, &$close) {
	switch ($position) {
		case 'head':
			if ($entries > 1) {
				$open[0] = '<li class="has-sub">'; $close[0] = '';
				$open[1] = '<ul><li>';	$close[1] = '</li>';
				$open[2] = '<li>';		$close[2] = '</li>';
				$close[9] = '</li></ul></li>';
			} else {
				$open[0] = '<li>'; $close[0] = '</li>';
				$close[9] = '</li>';
			}
			break;
		case 'mobile':
			$open[0] = '<li>'; $close[0] = '</li>';
			$open[1] = '<li>'; $close[1] = '</li>';
			$open[2] = '<li>'; $close[2] = '</li>';
			$close[9] = '</li>';
			break;
		case 'side':
			$open[0] = '<h2>';		$close[0] = '</h2>';
			$open[1] = '<ul><li>';	$close[1] = '</li>';
			$open[2] = '<li>';		$close[2] = '</li>';
			$close[9] = '</li></ul>';
	}
	$close_end = array_pop($close);
	if ($entries>1) {
		$i = 2;
		while ($i<$entries) {
			$open[$i+1] = $open[$i];
			$close[$i+1] = $close[$i];
			$i++;
		}
		$close[$entries-1] = $close_end;
	}
}
/**
 * Show a menu
 * @param array $items: first entry is main menu item, then sub menu items.
 *  format: 'link' => 'title', ex: 'bethico:howtos' => 'g:howtos'
 *  precede title with a: for admin, u: for user, e: for external, g: for guest
 *  will return empty parts if icon or lang not defined for item title
 * @param unknown $position: 'head', 'mobile', 'side'
 * @param string $class
 * @param string $tags
 */
function tpl_bethico_menu($position, $minimize, $items = array()) {

	global $bethico_icons;
	$class = 'm1-menu-full';
	if ($position != 'head') $minimize = false;
	$entries = array();
	$first = true;

	foreach ($items AS $entry => $link) {
		$page = explode(':', $entry);
		$acl = $page[0];
		if ($position != 'side' || !$first || tpl_getConf('sidebartitleicon')) $icon = (string) $bethico_icons[$page[1]];
		$title = tpl_getLang($page[1]);

		switch ($acl) {
			case 'h':	break;
			case 'e':	$entries[] = '<a href="'.$link.'" target="_blank">'.$icon.($minimize ? '<span class="'.$class.'"> '.$title.'</span>' : ' '.$title).'</a>'; break;
			case 'a':	if (tpl_bethico_user_group('admin')) $entries[] = '<a href="doku.php?id='.$link.'">'.$icon.($minimize ? '<span class="'.$class.'"> '.$title.'</span>' : ' '.$title).'</a>'; break;
			case 'u':	if (tpl_bethico_user_group('user'))  $entries[] = '<a href="doku.php?id='.$link.'">'.$icon.($minimize ? '<span class="'.$class.'"> '.$title.'</span>' : ' '.$title).'</a>'; break;
			default:	$entries[] = '<a href="doku.php?id='.$link.'">'.$icon.($minimize ? '<span class="'.$class.'"> '.$title.'</span>' : ' '.$title).'</a>';
		}
		$minimize = false;
		$first = false;
	}

	// get tags
	tpl_bethico_getTags($position, count($entries), $open, $close);

	// echo all menu entries
	foreach ($entries AS $i => $entry) echo $open[$i].$entry.$close[$i];
}
function tpl_bethico_login_menu($position) {

	global $lang, $bethico_icons, $INPUT;

	if ($position=='head') $first = true; else $first = false;
	$last = $first;
	$items = tpl_bethico_login_menu_items($position);
	foreach ($items AS $key => $item) {

		if ($key==0 && $INPUT->server->str('REMOTE_USER')) {
			$item->lang = $INPUT->server->str('REMOTE_USER');
			$icon = $bethico_icons['user'];
		} else {
			$icon = $bethico_icons['btn_'.$item->getType()].' ';
			if ($item->lang = tpl_getLang('btn_'.$item->getType()));
			elseif ($item->lang = tpl_getLang($item->getType()));
			elseif ($item->lang = $lang['btn_'.$item->getType()]);
			else $item->lang = $item->getType();
/*
			if ($override = tpl_getLang('btn_'.$item->getType())) $item->lang = $override;
			elseif ($override = tpl_getLang($item->getType())) $item->lang = $override;
			elseif (!$item->lang = $lang['btn_'.$item->getType()]) $item->lang = $item->getType();
*/
		}
		echo '<li'.($first ? ' class="has-sub"' : '').'>';
		switch ($item->getType()) {
			case 'top':
				echo '<a class="nolink" href="#">'.$icon.' '.$item->lang.'</a>';
				break;
/*
			case 'export_pdf':
			case 'twofactor_profile':
				$item->lang = tpl_getLang($item->getType());
*/
			default:
				echo '<a href="'.$item->getLink().'">'.$icon.' '.$item->lang.'</a>';
		}
		echo ($first ? '<ul>' : '</li>');
		$first = false;
	}
	if ($last) echo '</ul></li>';
}
